@@ -12,19 +12,18 @@ use IO::Pipe ;
 use IO::Select ;
 use Net::hostent ;
 
-my $VERSION = Base::Version . ' - Sat Jul 23 09:12:31 2016 - henkp' ;
+my $VERSION = Base::Version . ' - Mon Jan 17 18:14:46 2011 - henkp' ;
 my $DEF_CNF = join ', ', Mirmon -> config_list ;
 my $TIMEOUT = Base::DEF_TIMEOUT ;
 
 my $prog = substr $0, rindex ( $0, '/' ) + 1 ;
 my $Usage = <<USAGE ;
-Usage: $prog [-v] [-q] [-t timeout] [-c conf] [-get all|update|url <url>]
+Usage: $prog [ -v ] [ -q ] [ -t timeout ] [ -get opt ] [ -c conf ]
 option v   : be verbose
 option q   : be quiet
 option t   : set timeout ; default $TIMEOUT
-option get : get all       : probe all sites
-           : get update    : probe a selection of the sites (see doc)
-           : get url <url> : probe some <url> (in the mirror-list).
+option get : 'all'    : probe all sites
+           : 'update' : probe a selection of the sites (see doc)
 option c   : configuration file ; default search :
              ( $DEF_CNF )
 -------------------------------------------------------------------
@@ -46,30 +45,23 @@ use Getopt::Long ;
 Getopt::Long::config ( 'no_ignore_case' ) ;
 my %opt = () ;
 Usage '' unless GetOptions ( \%opt, qw(v q t=i get=s c=s version) ) ;
-Usage "Arg count\n" if @ARGV > 1 ;
-Usage "Arg count\n" if $opt{get} and $opt{get} eq 'url' and ! @ARGV ;
+Usage "Arg count\n" unless @ARGV == 0 ;
 
 if ( $opt{version} ) { printf "%s\n", Base::version () ; exit ; }
 
 $opt{v} ||= $opt{d} ;
 
-my $URL = shift ;
-
-my $M = Mirmon -> new ( $opt{c} ) ;
-$M -> conf -> timeout ( $opt{t} ) if $opt{t} ;
-
 my $get = $opt{get} ;
-if ( $get )
-  { Error "url $URL not in list"
-      if $get eq 'url' and ! $M -> state -> { $URL } ;
-    Error "unknown 'get option' '$get'" unless Base::is_get_opt ( $get ) ;
-  }
+if ( $get and ! Base::is_get_opt ( $get ) )
+  { Error "unknown 'get option' '$get'" ; }
 
 Mirmon::verbose ( $opt{v} ) ;
 Mirmon::debug   ( $opt{d} ) ;
 Mirmon::quiet   ( $opt{q} ) ;
 
-if ( $get ) { $M -> get_dates ( $get, $URL ) ; $M -> put_state ; }
+my $M = Mirmon -> new ( $opt{c} ) ;
+$M -> conf -> timeout ( $opt{t} ) if $opt{t} ;
+if ( $get ) { $M -> get_dates ( $get ) ; $M -> put_state ; }
 $M -> gen_page ( $get, $VERSION ) ;
 
 __END__
@@ -82,38 +74,20 @@ mirmon - monitor the state of mirrors
 
 =head1 SYNOPSIS
 
-  mirmon [-v] [-q] [-t timeout] [-c conf] [-get all|update|url url]
+  mirmon [ -v ] [ -q ] [ -t timeout ] [ -get opt ] [ -c conf ]
 
 =head1 OPTIONS
 
-=over 4
-
-=item B<-v>
-
-Be verbose ; B<mirmon> normally only reports
-errors and changes in the mirror list.
-
-=item B<-q>
-
-Be quiet.
-
-=item B<-t> I<timeout>
-
-Set the timeout ; the default is I<300>.
-
-=item B<-get> all | update | url <url>
-
-With B<all>, probe all sites.
-With B<update>, probe a selection of the sites ; see option C<max_poll> below.
-With B<url>, probe only the given I<url>, which must appear in the mirror-list.
-
-=item B<-c> I<name>
-
-Use config file I<name>. The default list is
-
-  ./mirmon.conf $HOME/.mirmon.conf /etc/mirmon.conf
-
-=back
+  option v   : be verbose
+  option q   : be quiet
+  option t   : set timeout [ default 300 ] ;
+  option get : 'all'    : probe all sites
+             : 'update' : probe a selection of the sites (see doc)
+  option c   : configuration file ; default list :
+               ./mirmon.conf $HOME/.mirmon.conf /etc/mirmon.conf
+  -------------------------------------------------------------------
+  Mirmon normally only reports errors and changes in the mirror list.
+  -------------------------------------------------------------------
 
 =head1 USAGE
 
@@ -195,24 +169,22 @@ A config file looks like this :
   |. part3
   +--------------------------------------------------
 
-=head2 required entries
+=head1 CONFIG FILE : required entries
 
-=over 4
-
-=item project_name I<name>
+=head2 project_name I<name>
 
 Specify a short plaintext name for the project.
 
   project_name Apache
   project_name CTAN
 
-=item project_url I<url>
+=head2 project_url I<url>
 
 Specify an url pointing to the 'home' of the project.
 
   project_url http://www.apache.org/
 
-=item mirror_list I<file-name>
+=head2 mirror_list I<file-name>
 
 Specify the file containing the mirrors to probe.
 
@@ -242,14 +214,14 @@ Two formats are supported :
 Note that in style 'plain' the third item is reserved for an
 optional email address : the site's contact address.
 
-Specify the required format with option C<list_style> (see below).
+Specify the required format with 'list_style' (see below).
 The default style is 'plain'.
 
-=item web_page I<file-name>
+=head2 web_page I<file-name>
 
 Specify where the html report page is written.
 
-=item icons I<directory-name>
+=head2 icons I<directory-name>
 
 Specify the directory where the icons can be found,
 relative to the I<web_page>, or relative to the
@@ -265,20 +237,20 @@ If/when the icons live in C</path/to/DOCUMENTROOT/icons/mirmon/>, specify
 
   icons /icons/mirmon
 
-=item probe I<program + arguments>
+=head2 probe I<program + arguments>
 
 Specify the program+args to probe the mirrors. Example:
 
-  probe /usr/bin/wget -q -O - -T %TIMEOUT% -t 1 %URL%TIME.txt
+  probe /usr/bin/wget -q -O - -T %TIMEOUT% -t 1 %URL%TIME
 
 Before the program is started, %TIMEOUT% and %URL% are
 substituted with the proper timeout and url values.
 
 Here it is assumed that each hour the root server writes
-a timestamp in /path/to/archive/TIME.txt, for instance with
+a timestamp in /path/to/archive/TIME, for instance with
 a crontab entry like
 
-  42 * * * * perl -e 'print time, "\n"' > /path/to/archive/TIME.txt
+  42 * * * * perl -e 'printf "%s\n", time' > /path/to/archive/TIME
 
 Mirmon reads one line of output from the probe and interprets
 the first word on that line as a timestamp ; for example :
@@ -290,45 +262,37 @@ the first word on that line as a timestamp ; for example :
 Mirmon is distributed with a program C<probe> that handles
 ftp, http and rsync urls.
 
-=item state I<file-name>
+=head2 state I<file-name>
 
 Specify where the file containing the state is written.
 
 The program reads this file on startup and writes the
 file when mirrors are probed (-get is specified).
 
-=item countries I<file-name>
+=head2 countries I<file-name>
 
 Specify the file containing the country codes;
 The file should contain lines like
 
-  us - United States
-  nl - Netherlands
+  us - united states
+  nl - netherlands
 
 The mirmon package contains a recent ISO list.
 
-I<Fake> domains like I<Backup>, I<Master> are allowed,
-and are listed first in the report ; lowercase-first
-fake domains (like I<backup>) are listed last.
+=head1 CONFIG FILE : optional entries
 
-=back
-
-=head2 optional entries
-
-=over 4
-
-=item max_probes I<number>
+=head2 max_probes I<number>
 
 Optionally specify the number of parallel probes (default 25).
 
-=item timeout I<seconds>
+=head2 timeout I<seconds>
 
 Optionally specify the timeout for the probes (default 300).
 
 After the last probe is started, the program waits for
 <timeout> + 10 seconds, cleans up and exits.
 
-=item project_logo I<logo>
+=head2 project_logo I<logo>
 
 Optionally specify (the SRC of the IMG of) a logo to be placed
 top right on the page.
@@ -336,20 +300,20 @@ top right on the page.
   project_logo /icons/apache.gif
   project_logo http://www.apache.org/icons/...
 
-=item htm_head I<html>
+=head2 htm_head I<html>
 
 Optionally specify some HTML to be placed before </HEAD>.
 
   htm_head
     <link REL=StyleSheet HREF="/style.css" TYPE="text/css">
 
-=item htm_top I<html>
+=head2 htm_top I<html>
 
 Optionally specify some HTML to be placed near the top of the page.
 
   htm_top testing 1, 2, 3
 
-=item htm_foot I<html>
+=head2 htm_foot I<html>
 
 Optionally specify HTML to be placed near the bottom of the page.
 
@@ -358,18 +322,18 @@ Optionally specify HTML to be placed near the bottom of the page.
     <A HREF="..."><IMG SRC="..." BORDER=0></A>
     <HR>
 
-=item put_histo top|bottom|nowhere
+=head2 put_histo top|bottom|nowhere
 
 Optionally specify where the age histogram must be placed.
 The default is 'top'.
 
-=item min_poll I<time-spec>
+=head2 min_poll I<time-spec>
 
 For 'min_poll' see next item. A I<time-spec> is a number followed by
 a unit 's' (seconds), or 'm' (minutes), or 'h' (hours), or 'd' (days).
 For example '3d' (three days) or '36h' (36 hours).
 
-=item max_poll I<time-spec>
+=head2 max_poll I<time-spec>
 
 Optionally specify the maximum probe interval. When the program is
 called with option '-get update', all sites are probed which are :
@@ -402,37 +366,35 @@ sites are probed at most six times a day.
 The default 'min_poll' is '1h' (1 hour).
 The default 'max_poll' is '4h' (4 hours).
 
-=item min_sync I<time-spec>
+=head2 min_sync I<time-spec>
 
 Optionally specify how often the mirrors are required to make an update.
 
 The default 'min_sync' is '1d' (1 day).
 
-=item max_sync I<time-spec>
+=head2 max_sync I<time-spec>
 
 Optionally specify the maximum allowable sync interval.
 
 Sites exceeding the limit will be considered 'old'.
 The default 'max_sync' is '2d' (2 days).
 
-=item always_get I<region ...>
+=head2 no_randomize
 
-Optionally specify a list of regions that must be probed always.
+To balance the probe load over the hourly mirmon runs,
+mirmon may probe a few extra randomly choosen mirrors :
 
-  always_get Master Tier1
+=over 4
 
-This is intended for I<fake regions> like I<Master> etc.
+=item * only if the the number of mirrors to probe is below average,
 
-=item no_randomize
+=item * at most 2% of the mirrors
 
-Mirmon tries to balance the probe load over the hourly mirmon runs.
-If the current run has a below average number of mirrors to probe,
-mirmon probes a few extra, randomly chosen mirrors, picked from the
-runs that have the highest load.
+=back
 
 If you don't want this behaviour, use B<no_randomize>.
 
-=item no_add_slash
+=head2 no_add_slash
 
 If the url part of a line in the mirror_list doesn't end
 in a slash ('/'), mirmon adds a slash and issues a warning
@@ -440,14 +402,14 @@ unless it is in quiet mode.
 
 If you don't want this behaviour, use B<no_add_slash>.
 
-=item list_style plain|apache
+=head2 list_style plain|apache
 
 Optionally specify the format ('plain' or 'apache') of the mirror-list.
 
 See the description of 'mirror_list' above.
 The default list_style is 'plain'.
 
-=item site_url I<site> I<url>
+=head2 site_url I<site> I<url>
 
 Optionally specify a substitute url for a site.
 
@@ -455,11 +417,11 @@ When access to a site is restricted (in Australia, for instance),
 another (sometimes secret) url can be used to probe the site.
 The <site> of an url is the part between '://' and the first '/'.
 
-=item env I<key> I<value>
+=head2 env I<key> I<value>
 
 Optionally specify an environment variable.
 
-=item include I<file-name>
+=head2 include I<file-name>
 
 Optionally specify a file to include.
 
@@ -469,19 +431,17 @@ C<include> was encountered.
 The include depth is unlimited. However, it is a fatal error to
 include a file twice under the same name.
 
-=item show
+=head2 show
 
 When the config processor encounters the 'show' command, it
 dumps the content of the current config to standout, if option
 C<-v> is specified. This is intented for debugging.
 
-=item exit
+=head2 exit
 
 When the config processor encounters the 'exit' command, it
 terminates the program. This is intented for debugging.
 
-=back
-
 =head1 STATE FILE FORMAT
 
 The state file consists of lines; one line per site.
@@ -496,16 +456,16 @@ The url as given in the mirror list.
 
 =item * field 2 : age
 
-The mirror's timestamp found by the last successful probe,
+The mirror's timestamp found by the last succesful probe,
 or 'undef' if no probe was ever successful.
 
 =item * field 3 : status last probe
 
 The status of the last probe, or 'undef' if the mirror was never probed.
 
-=item * field 4 : time last successful probe
+=item * field 4 : time last succesful probe
 
-The timestamp of the last successful probe or 'undef'
+The timestamp of the last succesful probe or 'undef'
 if the mirror was never successfully probed.
 
 =item * field 5 : probe history
@@ -546,11 +506,11 @@ The timestamp of the last probe, or 'undef' if the mirror was never probed.
 
 =item * The mirmon repository is here :
 
-  https://svn.science.uu.nl/repos/project.mirmon/trunk/
+  https://subversion.cs.uu.nl/repos/staff.henkp.mirmon/trunk/
 
 =item * The mirmon tarball is here :
 
-  http://www.staff.science.uu.nl/~penni101/mirmon/mirmon.tar.gz
+  http://people.cs.uu.nl/henkp/mirmon/mirmon.tar.gz
 
 =back
 
@@ -575,7 +535,7 @@ of the document root of your webserver.
 
 where
 
-  REPO = https://svn.science.uu.nl/repos/project.mirmon/trunk/
+  REPO = https://subversion.cs.uu.nl/repos/staff.henkp.mirmon/trunk/
 
 or download the package and unpack it.
 
@@ -613,13 +573,13 @@ The email addresses are optional.
   countries countries.list
   web_page DOCUMENTROOT/mirmon/index.html
   icons /mirmon/icons
-  probe /usr/bin/wget -q -O - -T %TIMEOUT% -t 1 %URL%TIME.txt
+  probe /usr/bin/wget -q -O - -T %TIMEOUT% -t 1 %URL%TIME
 
-This assumes the project's timestamp is in file C<TIME.txt>.
+This assumes the project's timestamp is in file C<TIME>.
 
 =item * If you have rsync urls, change the probe line to :
 
-  probe perl /usr/local/src/mirmon/probe -t %TIMEOUT% %URL%TIME.txt
+  probe perl /usr/local/src/mirmon/probe -t %TIMEOUT% %URL%TIME
 
 =item * Run mirmon :
 
@@ -641,9 +601,7 @@ The mirmon report should now be in 'DOCUMENTROOT/mirmon/index.html'
 
 =begin html
 
-<p>
-<a href="mirmon.pm.html">mirmon.pm(3)</a>
-</p>
+<A HREF="mirmon.pm.html">mirmon.pm(3)</A>
 
 =end html
 
@@ -657,33 +615,30 @@ mirmon.pm(3)
 
 =begin html
 
-  <p>
-  &copy; 2003-2016
-  <a href="http://www.staff.science.uu.nl/~penni101/">Henk P. Penning</a>,
-  <a href="http://www.uu.nl/faculty/science/EN/">Faculty of Science</a>,
-  <a href="http://www.uu.nl/">Utrecht University</a>
-  <br />
-  mirmon-2.11 - Sat Jul 23 09:12:31 2016 ; henkp ;
-  <a href="http://validator.w3.org/check?uri=referer">verify html</a>
-  </p>
+  &copy; 2003-2011
+  <A HREF="http://people.cs.uu.nl/henkp/">Henk P. Penning</A>,
+  <A HREF="http://www.cs.uu.nl/">Computer Science Department</A>,
+  <A HREF="http://www.uu.nl/">Utrecht University</A>
+  <BR>
+  mirmon-2.4 - Mon Jan 17 18:14:46 2011 ; henkp
 
 =end html
 
 =begin man
 
-  (c) 2003-2016 Henk P. Penning
-  Faculty of Science, Utrecht University
-  http://www.staff.science.uu.nl/~penni101/ -- penning@uu.nl
-  mirmon-2.11 - Sat Jul 23 09:12:31 2016 ; henkp
+  (c) 2003-2011 Henk P. Penning
+  Computer Science Department, Utrecht University
+  http://people.cs.uu.nl/henkp/ -- penning@cs.uu.nl
+  mirmon-2.4 - Mon Jan 17 18:14:46 2011 ; henkp
 
 =end man
 
 =begin text
 
-  (c) 2003-2016 Henk P. Penning
-  Faculty of Science, Utrecht University
-  http://www.staff.science.uu.nl/~penni101/ -- penning@uu.nl
-  mirmon-2.11 - Sat Jul 23 09:12:31 2016 ; henkp
+  (c) 2003-2011 Henk P. Penning
+  Computer Science Department, Utrecht University
+  http://people.cs.uu.nl/henkp/ -- penning@cs.uu.nl
+  mirmon-2.4 - Mon Jan 17 18:14:46 2011 ; henkp
 
 =end text
 
